@@ -78,7 +78,7 @@ class SliceWrapper(Iterable, Generic[WrappedType]):
 
         # Backwards-compatibility
         def convert_to_numpy():  # pragma: no cover
-            self.data = self.map(np.asarray)
+            self.data.update(self.map(np.asarray))
 
         self.convert_to_numpy = fannypack.utils.deprecation_wrapper(
             "SliceWrapper.convert_to_numpy() is deprecated -- please use "
@@ -88,7 +88,7 @@ class SliceWrapper(Iterable, Generic[WrappedType]):
 
     def __getitem__(self, index: Any) -> Any:
         """Unified interface for indexing into our wrapped object; shorthand for
-        `SliceWrapper.get(lambda v: v[index])`.
+        `SliceWrapper.map(lambda v: v[index])`.
 
         For iterables that are directly wrapped, this is equivalent to evaluating
         `data[index]`.
@@ -231,9 +231,37 @@ class SliceWrapper(Iterable, Generic[WrappedType]):
         else:
             assert False, "Extend is only supported for wrapped lists"
 
+    @overload
+    def map(
+        self: Union[
+            SliceWrapper[Dict[Any, List]],
+            SliceWrapper[Dict[Any, Tuple]],
+            SliceWrapper[Dict[Any, torch.Tensor]],
+            SliceWrapper[Dict[Any, np.ndarray]],
+        ],
+        function: Callable[[Any], MapOutputType],
+    ) -> Dict[Any, MapOutputType]:
+        pass
+
+    @overload
+    def map(
+        self: Union[
+            SliceWrapper[List],
+            SliceWrapper[Tuple],
+            SliceWrapper[torch.Tensor],
+            SliceWrapper[np.ndarray],
+        ],
+        function: Callable[[Any], MapOutputType],
+    ) -> MapOutputType:
+        pass
+
+    @overload
     def map(
         self, function: Callable[[Any], MapOutputType]
     ) -> Union[MapOutputType, Dict[Any, MapOutputType]]:
+        pass
+
+    def map(self, function):
         """Apply a function to all iterables within our wrapped data object.
 
         For iterables that are directly wrapped (eg lists), this is equivalent to
